FastCommand

Enum FastCommand 

pub enum FastCommand {
Show 20 variants CMD_TXRXOFF = 0, CMD_TX = 1, CMD_RX = 2, CMD_DTX = 3, CMD_DRX = 4, CMD_DTX_TS = 5, CMD_DRX_TS = 6, CMD_DTX_RS = 7, CMD_DRX_RS = 8, CMD_DTX_REF = 9, CMD_DRX_REF = 10, CMD_CCA_TX = 11, CMD_TX_W4R = 12, CMD_DTX_W4R = 13, CMD_DTX_TS_W4R = 14, CMD_DTX_RS_W4R = 15, CMD_DTX_REF_W4R = 16, CMD_CCA_TX_W4R = 17, CMD_CLR_IRQS = 18, CMD_DB_TOGGLE = 19,
}
Fast command enumeration to easily control the module

Variants



CMD_TXRXOFF = 0

Fast command to go to IDLE state and clears any events



CMD_TX = 1

Fast command to Immediate start of transmission



CMD_RX = 2

Fast command to Enable RX immediately



CMD_DTX = 3

Fast command to Delayed TX w.r.t. DX_TIME



CMD_DRX = 4

Fast command to Delayed RX w.r.t. DX_TIME



CMD_DTX_TS = 5

Fast command to Delayed TX w.r.t. TX timestamp + DX_TIME



CMD_DRX_TS = 6

Fast command to Delayed RX w.r.t. TX timestamp + DX_TIME



CMD_DTX_RS = 7

Fast command to Delayed TX w.r.t. RX timestamp + DX_TIME



CMD_DRX_RS = 8

Fast command to Delayed RX w.r.t. RX timestamp + DX_TIME



CMD_DTX_REF = 9

Fast command to Delayed TX w.r.t. DREF_TIME + DX_TIME



CMD_DRX_REF = 10

Fast command to Delayed RX w.r.t. DREF_TIME + DX_TIME



CMD_CCA_TX = 11

Fast command to TX if no preamble detected



CMD_TX_W4R = 12

Fast command to Start TX immediately, then when TX is done, enable the receiver



CMD_DTX_W4R = 13

Fast command to Delayed TX w.r.t. DX_TIME, then enable receiver



CMD_DTX_TS_W4R = 14

Fast command to Delayed TX w.r.t. TX timestamp + DX_TIME, then enable receiver



CMD_DTX_RS_W4R = 15

Fast command to Delayed TX w.r.t. RX timestamp + DX_TIME, then enable receiver



CMD_DTX_REF_W4R = 16

Fast command to Delayed TX w.r.t. DREF_TIME + DX_TIME, then enable receiver



CMD_CCA_TX_W4R = 17

Fast command to TX packet if no preamble detected, then enable receiver



CMD_CLR_IRQS = 18

Fast command to Clear all interrupt events



CMD_DB_TOGGLE = 19

Fast command to Toggle double buffer pointer / notify the device that the host has finished processing the received buffer/data.