#[repr(C)]pub struct Duration(/* private fields */);Expand description
A duration between two instants in DW3000 system time
Internally uses the same 40-bit timestamps that the DW3000 uses.
Implementations
Sourceimpl Duration
impl Duration
Sourcepub fn new(value: u64) -> Option<Self>
pub fn new(value: u64) -> Option<Self>
Creates a new instance of Duration
The given value must fit in a 40-bit timestamp, so:
0 <= value <= 2^40 - 1
Returns Some(...), if value is within the valid range, None if it
isn’t.
Example
use dw3000_ng::time::{
TIME_MAX,
Duration,
};
let valid_duration = Duration::new(TIME_MAX);
let invalid_duration = Duration::new(TIME_MAX + 1);
assert!(valid_duration.is_some());
assert!(invalid_duration.is_none());Sourcepub fn from_nanos(nanos: u32) -> Self
pub fn from_nanos(nanos: u32) -> Self
Creates an instance of Duration from a number of nanoseconds, rounding to the nearest
On the DW3000, the TX_TIME/RX_TIME registers have a resolution of 40-bits and a unit of 1/(128499.210^6) seconds. This means that 1 nanosecond is 63.8976 DW3000 time units.
We do this with fixed point arithmetic, where (dividend + (divisor / 2)) / divisor